==> coRanking_0.2.2.tar.gz: coRanking/README.md <==
# coRanking
![R](https://github.com/gdkrmr/coRanking/workflows/R/badge.svg?branch=master)
[![Travis Build Status](https://travis-ci.org/gdkrmr/coRanking.svg?branch=master)](https://travis-ci.org/gdkrmr/coRanking)
[![Coverage Status](https://img.shields.io/codecov/c/github/gdkrmr/coRanking/master.svg)](https://codecov.io/github/gdkrmr/coRanking?branch=master)
[![CRAN\_Status\_Badge](http://www.r-pkg.org/badges/version/coRanking)](https://cran.r-project.org/package=coRanking)
[![DOI](https://zenodo.org/badge/69355803.svg)](https://zenodo.org/badge/latestdoi/69355803)


The Co-Ranking Matrix

An implementation of the Co-Ranking matrix and derived methods to
assess the quality of dimensionality reductions

## Installing

Install the development version:
```R
## install.packages("devtools")
devtools::install_github("gdkrmr/coRanking")
```

Install from CRAN:
```R
install.packages("coRanking")
```

Use it:
```R
library(coRanking)
```

## Citing
The corresponding publication can be found
[here](https://journal.r-project.org/archive/2018/RJ-2018-039/index.html "dimRed
and coRanking - Unifying Dimensionality Reduction in R"), please cite if you use
it:

```bibtex
@article{RJ-2018-039,
  author = {Guido Kraemer and Markus Reichstein and Miguel D. Mahecha},
  title = {{dimRed and coRanking---Unifying Dimensionality Reduction in R}},
  year = {2018},
  journal = {{The R Journal}},
  url = {https://journal.r-project.org/archive/2018/RJ-2018-039/index.html},
  pages = {342--358},
  volume = {10},
  number = {1}
}
```

==> coRanking_0.2.5.tar.gz: coRanking/README.md <==
# coRanking

[![docs](https://img.shields.io/badge/docs-dev-blue.svg)](https://coranking.guido-kraemer.com)
[![R](https://github.com/gdkrmr/DRR/actions/workflows/r.yml/badge.svg)](https://github.com/gdkrmr/DRR/actions/workflows/r.yml)
[![codecov](https://codecov.io/gh/gdkrmr/coRanking/branch/master/graph/badge.svg?token=vEkHGuhNHQ)](https://app.codecov.io/gh/gdkrmr/coRanking)
[![CRAN\_Status\_Badge](https://www.r-pkg.org/badges/version/coRanking)](https://cran.r-project.org/package=coRanking)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3365908.svg)](https://doi.org/10.5281/zenodo.3365908)


The Co-Ranking Matrix

An implementation of the Co-Ranking matrix and derived methods to
assess the quality of dimensionality reductions

## Installing

Install the development version:
```R
## install.packages("devtools")
devtools::install_github("gdkrmr/coRanking")
```

Install from CRAN:
```R
install.packages("coRanking")
```

Use it:
```R
library(coRanking)
```

## Citing
The corresponding publication can be found
[here](https://journal.r-project.org/archive/2018/RJ-2018-039/index.html "dimRed
and coRanking - Unifying Dimensionality Reduction in R"), please cite if you use
it:

```bibtex
@article{RJ-2018-039,
  author = {Guido Kraemer and Markus Reichstein and Miguel D. Mahecha},
  title = {{dimRed and coRanking---Unifying Dimensionality Reduction in R}},
  year = {2018},
  journal = {{The R Journal}},
  url = {https://journal.r-project.org/archive/2018/RJ-2018-039/index.html},
  pages = {342--358},
  volume = {10},
  number = {1}
}
```
